@@ -45,7 +45,11 @@ class Annotation(es.Model):
         q = super(Annotation, cls)._build_query(offset, limit, **kwargs)
 
         if current_app.config.get('AUTHZ_ON'):
-            q['query'] = authz.permissions_filter(q['query'], g.user)
+            f = authz.permissions_filter(g.user)
+            if not f:
+                return False # Refuse to perform the query
+            q['query'] = {'filtered': {'query': q['query'],
+                                       'filter': f}}
 
         return q
 
