@@ -5,7 +5,9 @@ from flask import _request_ctx_stack
 
 class ElasticSearch(object):
 
-    """Thin wrapper around an ElasticSearch connection to make connection handling
+    """
+
+    Thin wrapper around an ElasticSearch connection to make connection handling
     transparent in a Flask application. Usage:
 
         app = Flask(__name__)
@@ -19,6 +21,7 @@ class ElasticSearch(object):
             app = Flask(__name__)
             es.init_app(app)
             return app
+
     """
 
     def __init__(self, app=None):
@@ -31,7 +34,7 @@ class ElasticSearch(object):
         self.Model = make_model(self)
 
     def init_app(self, app):
-        app.config.setdefault('ELASTICSEARCH_HOST', '127.0.0.1:9200')
+        app.config.setdefault('ELASTICSEARCH_HOST', 'http://127.0.0.1:9200')
         app.config.setdefault('ELASTICSEARCH_INDEX', app.name)
 
         if not hasattr(app, 'extensions'):
@@ -39,7 +42,10 @@ class ElasticSearch(object):
         app.extensions['elasticsearch'] = self
 
     def get_app(self):
-        """Helper method that implements the logic to look up an application.
+        """
+
+        Helper method that implements the logic to look up an application.
+
         """
         if self.app is not None:
             return self.app
@@ -82,11 +88,9 @@ class _Model(dict):
     def fetch(cls, id):
         try:
             doc = cls.es.conn.get(cls.es.index, cls.__type__, id)
-        # We should be more specific than this, but pyes doesn't raise the
-        # correct exception for missing documents at the moment
-        except pyes.exceptions.ElasticSearchException:
+        except pyes.exceptions.NotFoundException:
             return None
-        return cls(doc['_source'], id=id)
+        return cls(doc, id=id)
 
     @classmethod
     def _build_query(cls, offset=0, limit=20, **kwargs):
@@ -114,13 +118,17 @@ class _Model(dict):
     @classmethod
     def search(cls, **kwargs):
         q = cls._build_query(**kwargs)
-        res = cls.es.conn.search(q, cls.es.index, cls.__type__)
+        if not q:
+            return []
+        res = cls.es.conn.search_raw(q, cls.es.index, cls.__type__)
         docs = res['hits']['hits']
         return [cls(d['_source'], id=d['_id']) for d in docs]
 
     @classmethod
     def count(cls, **kwargs):
         q = cls._build_query(**kwargs)
+        if not q:
+            return 0
         res = cls.es.conn.count(q['query'], cls.es.index, cls.__type__)
         return res['count']
 
